#
# Evaluation code for sentence prediction in Charades
# This script evaluates prediction on the original script
# For details please see the Charades paper
#
# run as follows:
# python evalcharades.py test_submission_caption.txt ~/Charades_v1_test.csv
# 
# Gunnar Atli Sigurdsson, 2016
# Adapted from COCO Evaluation code. See License
# 

from pycocotools.coco import COCO
from pycocoevalcap.charadeseval import COCOEvalCap
import csv
import sys

submissionfile = sys.argv[1]
charadesfile = sys.argv[2]

gts = {}
pred = {}
with open(charadesfile) as f:
    reader = csv.DictReader(f)
    for row in reader:
        id = row['id']
        desc = row['descriptions'].split(';')
        script = row['script']
        gts[id] = [{'image_id': id, 'caption': d} for d in [script]]


with open(submissionfile) as f:
    for line in f:
        id = line.strip().split(' ')[0]
        if not id in gts: 
            sys.stderr.write('Warning: Prediction not in ground truth: {}\n'.format(id))
            continue
        desc = ' '.join(line.strip().split(' ')[1:])
        pred[id] = [{'image_id': id, 'caption': desc.replace('"','')}]

testids = gts.keys()
cocoEval = COCOEvalCap(gts, pred, testids)

# evaluate results
cocoEval.evaluate()

# print output evaluation scores
for metric, score in cocoEval.eval.items():
    print '%s: %.3f'%(metric, score)
